# Diamond E

A module to test diamond dependencies

## Install
```bash
$ python3 -m pip install diamond-e
```

## Usage 
```python3
from diamond import e

e.e()
```

OR

```python3
from diamond.e import e

e()
```
